#!/usr/bin/python
# -*- coding: utf-8 -*-
"""
    Un hola_mundo con Glade y PyGTK
    Versión 2: Añadimos algunos elementos gráficos extra y una ventana de
               información sobre el programa
    Profesores de Paradigmas de Programación
    Curso 2010/11
"""

import gtk

class holamundo():
    """ 
        Clase responsable de la interfaz
    """
    def __init__(self):
        """ Inicialización """
        # Cargamos la interfaz generada con glade
        self.glade=gtk.Builder()
        self.glade.add_from_file('hola.glade')

        # Podemos extraer algunos de los objetos que forman la interfaz
        # Utilizamos para ello el nombre que identifica al widget en glade
        self.ventana=self.glade.get_object('window1')
        self.ayuda=self.glade.get_object('dialogo_ayuda')

        # La lista de los botones que aparecen dentro de tabla
        self.pulsadores=self.glade.get_object('tabla').get_children()

        # También podemos cambiar la etiqueta que aparece en el botón
        for i in range(len(self.pulsadores)):
            self.pulsadores[i].set_label("0")

        # Conectamos todos los eventos descritos en la interfaz con sus
        # correspondientes manejadores. Cuando se active la señal (al pulsar
        # el botón, por ejemplo, se llamará al correspondiente método de
        # esta clase.
        self.glade.connect_signals(self)

        # Si no hemos hecho visible la ventana desde glade, podemos hacerlo
        # desde el código
        self.ventana.show()

    def on_window1_delete_event(self,widget,event):
        """ Gestión del borrado de la ventana principal """
        # Para los eventos además del widget nos envían el evento
        # Este evento contiene información extra sobre lo que ha ocurrido en
        # la ventana (tecla pulsada, botón pulsado,...)
        print "Señal para cerrar la ventana"
        gtk.main_quit()
        # Si no devolvemos nada, el evento no se considera procesado, se
        # retransmite y acaba siendo una destrucción de la ventana. Si
        # quisieramos evitar la destrucción de la ventana (mediante una
        # ventana para pedir información, por ejemplo) habría que devolver
        # True
        print "Fuera del bucle de control de eventos"

    def on_ayuda_activado(self,widget):
        """ Gestión del botón de ayuda """
        print "Ayuda"
        self.ayuda.show()

    def on_dialogo_ayuda_response(self,widget,event):
        """ Gestión del cierre del diálogo de ayuda """
        # Han pulsado el botón close del diálogo de ayuda
        # o han cerrado la ventana de ayuda con el aspa
        print "Cerrando ayuda"
        self.ayuda.hide()

    def on_dialogo_ayuda_delete_event(self,widget,event):
        """ Gestión de la destrucción del diálogo de ayuda """
        # Intentan destruir el diálogo de ayuda
        print "No destruyo el diálogo de ayuda"
        # Si no devuelves True, el evento se transforma en un evento destroy
        # que elimina la ventana, al volver a pedir ayuda aparecerá un
        # error.
        return True

    def on_pulsador_clicked(self,widget):
        """ Gestión de la pulsación de alguno de los 9 botones de la caja """
        # Un único manejador para todos los botones. Podemos distinguir el
        # botón pulsado porque nos pasan el widget, de modo que lo
        # comparamos con los de la lista pulsadores
        print "Click sobre el pulsador",
        for i in range(len(self.pulsadores)):
            if self.pulsadores[i]==widget:
                # Pero ojo, porque los pulsadores han entrado en orden
                # inverso
                print 8-i,
                # Una sencilla fórmula permite deducir sus coordenadas
                print "esto es el pulsador (", 
                print (8-i)//3+1,
                print ",",
                print (8-i)%3+1,
                print ")"
                # También se le puede colocar una imagen
                # Pero ojo, hay que crear una nueva para cada botón
                imagen=gtk.Image()
                imagen.set_from_file("1.png")
                self.pulsadores[i].set_image(imagen)
                self.pulsadores[i].set_label("")
        
# Para lanzar la aplicación...
if __name__=='__main__':
    # Instanciamos la interfaz
    app=holamundo()
    # Lanzamos el bucle de gestión de eventos
    gtk.main()
    print "Termina el programa"
